package
Version:
v0.0.0-...-eecad4e
Opens a new window with list of versions in this module.
Published: Jun 17, 2019
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func MakeAB(aNonce, sNonce, apMac, cliMac []byte) ([]byte, []byte)
-
func MakeMIC(pwd, ssid string, A, B, data []byte, isWpa bool) ([]byte, []byte, []byte)
-
func PRF(key, A, B []byte) []byte
func MakeAB(aNonce, sNonce, apMac, cliMac []byte) ([]byte, []byte)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.